.. :Tutorials:

Tutorials
---------
Two different ways have been thought of on how to use MJOLNIR depending on the situation and  problem at hand. Generating figures, performing fits, and refining plots are all
intended to be done through a python script, while other questions like generating a list of all of the files in a folder with useful information or inspecting a normalization 
file is more useful to be done through a command line interface. Further specification is available in the tutorial overviews below.

.. toctree::
   :maxdepth: 2

   Scripting
   Commandline
